package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
)

var _ DcWorkingUfModel = (*customDcWorkingUfModel)(nil)

type (
	// DcWorkingUfModel is an interface to be customized, add more methods here,
	// and implement the added methods in customDcWorkingUfModel.
	DcWorkingUfModel interface {
		dcWorkingUfModel
		FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingUf, error)
	}

	customDcWorkingUfModel struct {
		*defaultDcWorkingUfModel
	}
)

// NewDcWorkingUfModel returns a model for the database table.
func NewDcWorkingUfModel(conn sqlx.SqlConn) DcWorkingUfModel {
	return &customDcWorkingUfModel{
		defaultDcWorkingUfModel: newDcWorkingUfModel(conn),
	}
}

func (m *defaultDcWorkingUfModel) FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingUf, error) {
	var resp DcWorkingUf
	query := fmt.Sprintf("select %s from %s where `project_id` = ? and `device_code` = ? order by c_time desc limit 1", dcWorkingUfRows, m.table)
	err := m.conn.QueryRowCtx(ctx, &resp, query, projectId, deviceCode)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}
